<template>
  <div>
    <div style="text-align: left; font-size: 12px">
      <activity v-for="activity in view.activities" :key="activity.id" :info="activity" />@
    </div>
    <el-divider></el-divider>
    <div>
      <form_searchform
        :appId="openParams.appId"
        :viewId="openParams.actionContent"
        @onSearch="onSearch"
        ref="searchform"
      />
      <el-table v-if="view.columns && view.columns.length>0" :data="tableData" style="width: 100%">
        <el-table-column type="selection" ></el-table-column>
        <template v-for="column in view.columns">
          <el-table-column
            :key="column.id"
            :prop="column.id"
            :label="column.name"
            :width="column.width"
          >
            <template slot-scope="scope">
              <template v-if="status[scope.row.docId]==1">
                <component name="rowformTemplate" :is="rowdatas[scope.row.docId].component"></component>
              </template>
              <template v-else>{{scope.row[column.id]}}</template>
            </template>
          </el-table-column>
        </template>
        <el-table-column fixed="right" :label="$t('op')" width="100">
          <template slot-scope="scope">
            <el-button
              v-if="status[scope.row.docId]!=1"
              @click="doEdit(scope.row)"
              type="text"
              size="small"
            >{{$t('edit')}}</el-button>
            <el-button
              v-if="status[scope.row.docId]==1"
              @click="doConfirm(scope.row)"
              type="text"
              size="small"
            >{{$t('verify')}}</el-button>
            <el-button
              v-if="status[scope.row.docId]!=1"
              @click="doRemove(scope.row)"
              type="text"
              size="small"
            >{{$t('del')}}</el-button>
            <el-button
              v-if="status[scope.row.docId]==1"
              @click="doCancel(scope.row)"
              type="text"
              size="small"
            >{{$t('cancel')}}</el-button>
          </template>
        </el-table-column>
      </el-table>
      <!-- <mdialog ref="dialog" width="90%" /> -->
    </div>
  </div>
</template>

<script>
import form_searchform from "@/components/form_searchform.vue";
import activity from "@/components/activity.vue";
// import mdialog from "@/components/dialog.vue";
import API from "@/api.js";
import Constant from "@/Constant.js";
export default {
  name: "view-gridview",
  props: ["openParams"],
  components: {
    form_searchform,
    activity,
    // mdialog
  },
  data: function() {
    return {
      rowdatas: {},
      status: {} //存放编辑状态
    };
  },
  computed: {
    view() {
      return this.$parent.view;
    },
    tableData() {
      let docs =
        this.view.data && this.view.data.data ? this.view.data.data : undefined;
      let tds = [];
      if (docs)
        docs.forEach(doc => {
          let rows = {};
          rows.formId = doc.formId;
          rows.docId = doc.id;
          for (var key in doc.items) {
            let items = doc.items[key];
            rows[key] = items.value;
          }
          tds.push(rows);
        });
      return tds;
    }
  },

  methods: {
    onSearch(searchData) {
      this.$parent.initView({
        appId: this.openParams.appId,
        viewId: this.openParams.actionContent,
        data: searchData,
        exparams: {
          currpage: this.currentPage,
          lines: this.pagesize
        }
      });
    },

    //进入编辑状态
    doEdit(row) {
      API.getForm(
        this.openParams.appId,
        row.formId,
        row.docId,
        {},
        {
          onSucess: response => {
            let fields = response.data.data.fields;
            let formdata = response.data.data;
            //以docId为Key存储formData
            this.$set(this.rowdatas, row.docId, formdata);
            fields.forEach(fld => {
              let template = "";
              if (fld.formField == "InputField") {
                template = "<div><o-input id='" + fld.id + "'></o-input></div>";
              } else if (fld.formField == "RadioField") {
                template = "<div><o-radio id='" + fld.id + "'></o-radio></div>";
              } else if (fld.formField == "TextareaField") {
                template = "<div><o-textarea id='" + fld.id + "'></o-textarea></div>";
              }

              this.rowdatas[row.docId].component = {
                methods: {
                  findField(id) {
                    for (let i = 0; i < fields.length; i++) {
                      let fld = fields[i];
                      if (id == fld.id) return fld;
                    }
                    //TODO:临时处理隐藏字段--Jarod
                    return {
                      id: id,
                      displayType: Constant.PermissionType_HIDDEN,
                      hiddenValue: ""
                    };
                  }
                },
                template: template
              };
            });
            this.$set(this.status, row.docId, 1);
          }
        }
      );
    },
    //确定记录
    doConfirm(row) {
      this.$set(this.status, row.docId, 0);
    },
    //取消记录
    doCancel(row) {
      this.$set(this.status, row.docId, 0);
    },
    //新建记录
    doCreate() {
      API.getDocumentEmpty(
        this.openParams.appId,
        this.view.relatedForm,
        {},
        {
          onSucess: response => {
            this.view.data.data.push({
              formId: this.view.relatedForm,
              id: response.data.data.id,
              items: {}
            });

            //转变编辑状态
            this.doEdit({
              formId: this.view.relatedForm,
              docId: response.data.data.id
            });
          }
        }
      );
    },
    //删除记录
    doRemove(row) {
      let i = -1;
      this.view.data.data.forEach((doc, index) => {
        if (doc.id == row.docId) i = index;
      });
      this.view.data.data.splice(i, 1);
    }
  }
};
</script>